@@ -1,8 +1,8 @@
 # encoding: utf-8
 
 """
-This file documents our base "public" API, as defined by using the PIL Image
-class with almost all methods stubbed out to return NotImplementedError()
+Our base "public" API, which is essentially the PIL Image class with almost
+all methods raising :exc:`NotImplementedError`
 
 Backends are implemented by subclassing and actually doing something with the
 results
@@ -49,6 +49,12 @@ CONTAINER = 2
 
 
 class Image(object):
+    """
+    Base class for all NativeImaging backends
+
+    Should be compatible with PIL.Image or raise NotImplementedError()
+    """
+
     format = None
     format_description = None
     im = None
@@ -107,8 +113,9 @@ class Image(object):
 
     def crop(self, box=None):
         """Return a cropped version of the image
-        @param The crop rectangle, as a (left, upper, right, lower)-tuple.
-        @return An Image object.
+
+        :param box: The crop rectangle, as a (left, upper, right, lower)-tuple.
+        :rtype: :class:Image object
         """
         raise NotImplementedError()
 
@@ -127,11 +134,10 @@ class Image(object):
         """Apply environment filter to image
 
         Filters this image using the given filter. For a list of available
-        filters, see the `ImageFilter` module.
+        filters, see the :mod:`ImageFilter` module.
 
-        @param filter Filter kernel.
-        @return An Image object.
-        @see ImageFilter
+        :param filter: Filter kernel.
+        :rtype: :class:Image object
         """
 
         raise NotImplementedError()
@@ -141,7 +147,7 @@ class Image(object):
         Returns a tuple containing the name of each band in this image.
         For example, getbands on an RGB image returns ("R", "G", "B").
 
-        @return A tuple containing band names.
+        :return: A tuple containing band names.
         """
         raise NotImplementedError()
 
@@ -151,7 +157,7 @@ class Image(object):
         Calculates the bounding box of the non-zero regions in the
         image.
 
-        @return The bounding box is returned as a 4-tuple defining the
+        :return: The bounding box is returned as a 4-tuple defining the
            left, upper, right, and lower pixel coordinate. If the image
            is completely empty, this method returns None.
         """
@@ -163,10 +169,10 @@ class Image(object):
         """Get colors from image, up to given limit
         Returns a list of colors used in this image.
 
-        @param maxcolors Maximum number of colors.  If this number is
+        :param maxcolors: Maximum number of colors.  If this number is
            exceeded, this method returns None.  The default limit is
            256 colors.
-        @return An unsorted list of (count, pixel) values.
+        :return: An unsorted list of (count, pixel) values.
         """
 
         raise NotImplementedError()
@@ -181,7 +187,7 @@ class Image(object):
         Gets the the minimum and maximum pixel values for each band in
         the image.
 
-        @return For a single-band image, a 2-tuple containing the
+        :return: For a single-band image, a 2-tuple containing the
            minimum and maximum pixel value.  For a multi-band image,
            a tuple containing one 2-tuple for each band.
         """
@@ -190,7 +196,7 @@ class Image(object):
     def getpalette(self):
         """Get palette contents
 
-        @return A list of color values [r, g, b, ...], or None if the
+        :return: A list of color values [r, g, b, ...], or None if the
            image has no palette.
         """
 
@@ -199,8 +205,8 @@ class Image(object):
     def getpixel(self, xy):
         """Get pixel value
 
-        @param xy The coordinate, given as (x, y).
-        @return The pixel value.  If the image is a multi-layer image,
+        :param xy: The coordinate, given as (x, y).
+        :return: The pixel value.  If the image is a multi-layer image,
            this method returns a tuple.
         """
 
@@ -211,7 +217,7 @@ class Image(object):
 
         Returns the horizontal and vertical projection.
 
-        @return Two sequences, indicating where there are non-zero
+        :return: Two sequences, indicating where there are non-zero
             pixels along the X-axis and the Y-axis, respectively.
         """
 
@@ -234,9 +240,8 @@ class Image(object):
         image must have the same size as the image, and be either a
         bi-level image (mode "1") or a greyscale image ("L").
 
-        @def histogram(mask=None)
-        @param mask An optional mask.
-        @return A list containing pixel counts.
+        :param mask: An optional mask.
+        :return: A list containing pixel counts.
         """
 
         raise NotImplementedError()
@@ -251,7 +256,7 @@ class Image(object):
         must match the size of the region.
 
         If the modes don't match, the pasted image is converted to the
-        mode of this image (see the {@link #Image.convert} method for
+        mode of this image (see the :meth:`Image.convert` method for
         details).
 
         Instead of an image, the source can be a integer or tuple
@@ -270,8 +275,8 @@ class Image(object):
         ignored.  You can work around this by using the same image as
         both source image and mask.
 
-        @param im Source image or pixel value (integer or tuple).
-        @param box An optional 4-tuple giving the region to paste into.
+        :param im: Source image or pixel value (integer or tuple).
+        :param box: An optional 4-tuple giving the region to paste into.
            If a 2-tuple is used instead, it's treated as the upper left
            corner.  If omitted or None, the source is pasted into the
            upper left corner.
@@ -279,8 +284,8 @@ class Image(object):
            If an image is given as the second argument and there is no
            third, the box defaults to (0, 0), and the second argument
            is interpreted as a mask image.
-        @param mask An optional mask image.
-        @return An Image object.
+        :param mask: An optional mask image.
+        :rtype: :class:Image object
 
         """
 
@@ -289,15 +294,15 @@ class Image(object):
     def point(self, lut, mode=None):
         """Maps this image through a lookup table or function.
 
-        @param lut A lookup table, containing 256 values per band in the
+        :param lut: A lookup table, containing 256 values per band in the
            image. A function can be used instead, it should take a single
            argument. The function is called once for each possible pixel
            value, and the resulting table is applied to all bands of the
            image.
-        @param mode Output mode (default is same as input).  In the
+        :param mode: Output mode (default is same as input).  In the
            current version, this can only be used if the source image
            has mode "L" or "P", and the output has mode "1".
-        @return An Image object.
+        :rtype: :class:Image object
 
         """
 
@@ -309,7 +314,7 @@ class Image(object):
         does not have an alpha layer, it's converted to "LA" or "RGBA".
         The new layer must be either "L" or "1".
 
-        @param im The new alpha layer.  This can either be an "L" or "1"
+        :param im: The new alpha layer.  This can either be an "L" or "1"
            image having the same size as this image, or an integer or
            other color value.
 
@@ -326,9 +331,9 @@ class Image(object):
         sequence ends.  The scale and offset values are used to adjust
         the sequence values: pixel = value*scale + offset.
 
-        @param data A sequence object.
-        @param scale An optional scale value.  The default is 1.0.
-        @param offset An optional offset value.  The default is 0.0.
+        :param data: A sequence object.
+        :param scale: An optional scale value.  The default is 1.0.
+        :param offset: An optional offset value.  The default is 0.0.
         """
 
         raise NotImplementedError()
@@ -339,19 +344,15 @@ class Image(object):
 
     def putpixel(self, xy, value):
         """
-        Modifies the pixel at the given position. The colour is given as
-        a single numerical value for single-band images, and a tuple for
+        Modifies the pixel at the given position. The colour is given as a
+        single numerical value for single-band images, and a tuple for
         multi-band images.
 
-        Note that this method is relatively slow.  For more extensive
-        changes, use {@link #Image.paste} or the ImageDraw module
-        instead.
+        Note that this method is relatively slow. For more extensive changes,
+        use :meth:`Image.paste` or the :mod:`ImageDraw` module instead.
 
-        @param xy The pixel coordinate, given as (x, y).
-        @param value The pixel value.
-        @see #Image.paste
-        @see #Image.putdata
-        @see ImageDraw
+        :param xy: The pixel coordinate, given as (x, y).
+        :param value: The pixel value.
         """
 
         raise NotImplementedError()
@@ -360,17 +361,15 @@ class Image(object):
         """
         Returns a resized copy of this image.
 
-        @def resize(size, filter=NEAREST)
-        @param size The requested size in pixels, as a 2-tuple:
+        :param tuple size: The requested size in pixels, as a 2-tuple:
            (width, height).
 
-        TODO: Revisit the filter description:
-        @param filter An optional resampling filter.  This can be
+        :param filter: An optional resampling filter.  This can be
            one of NEAREST (use nearest neighbour), BILINEAR
            (linear interpolation in a 2x2 environment), BICUBIC
            (cubic spline interpolation in a 4x4 environment), or
            ANTIALIAS (a high-quality downsampling filter).
-        @return An Image object.
+        :rtype: :class:Image object
         """
 
         raise NotImplementedError()
@@ -381,19 +380,18 @@ class Image(object):
         copy of this image, rotated the given number of degrees counter
         clockwise around its centre.
 
-        @def rotate(angle, filter=NEAREST)
-        @param angle In degrees counter clockwise.
-        @param filter An optional resampling filter.  This can be
+        :param angle: In degrees counter clockwise.
+        :param filter: An optional resampling filter.  This can be
            one of NEAREST (use nearest neighbour), BILINEAR
            (linear interpolation in a 2x2 environment), or BICUBIC
            (cubic spline interpolation in a 4x4 environment).
            If omitted, or if the image has mode "1" or "P", it is
            set NEAREST.
-        @param expand Optional expansion flag.  If true, expands the output
+        :param expand: Optional expansion flag.  If true, expands the output
            image to make it large enough to hold the entire rotated image.
            If false or omitted, make the output image the same size as the
            input image.
-        @return An Image object.
+        :rtype: :class:Image object
         """
 
         raise NotImplementedError()
@@ -414,36 +412,36 @@ class Image(object):
         implement the seek, tell, and write
         methods, and be opened in binary mode.
 
-        @def save(file, format=None, **options)
-        @param file File name or file object.
-        @param format Optional format override.  If omitted, the
+        :param file: File name or file object.
+        :param format: Optional format override.  If omitted, the
            format to use is determined from the filename extension.
            If a file object was used instead of a filename, this
            parameter should always be used.
-        @param **options Extra parameters to the image writer.
-        @return None
-        @exception KeyError If the output format could not be determined
-           from the file name.  Use the format option to solve this.
-        @exception IOError If the file could not be written.  The file
-           may have been created, and may contain partial data.
+        :param params: Extra parameters to the image writer.
+        :return: None
+        :raises: :exc:`KeyError` If the output format could not be determined
+                from the file name.  Use the format option to solve this.
+        :raises: :exc:`IOError` If the file could not be written. The file may
+                have been created, and may contain partial data.
         """
 
         raise NotImplementedError()
 
     def seek(self, frame):
         """
-        Seeks to the given frame in this sequence file. If you seek
-        beyond the end of the sequence, the method raises an
-        EOFError exception. When a sequence file is opened, the
-        library automatically seeks to frame 0.
+        Seeks to the given frame in this sequence file. If you seek beyond the
+        end of the sequence, the method raises an EOFError exception. When a
+        sequence file is opened, the library automatically seeks to frame 0.
 
-        Note that in the current version of the library, most sequence
-        formats only allows you to seek to the next frame.
+        Note that in the current version of the library, most sequence formats
+        only allows you to seek to the next frame.
 
-        @param frame Frame number, starting at 0.
-        @exception EOFError If the call attempts to seek beyond the end
-            of the sequence.
-        @see #Image.tell
+        :param frame: Frame number, starting at 0.
+
+        :exception: :exc:`EOFError` If the call attempts to seek beyond the
+                    end of the sequence.
+
+        See :meth:`Image.tell`
         """
 
         raise NotImplementedError()
@@ -459,9 +457,9 @@ class Image(object):
         On Windows, it saves the image to a temporary BMP file, and uses the
         standard BMP display utility to show it (usually Paint).
 
-        @def show(title=None)
-        @param title Optional title to use for the image window,
+        :param title: Optional title to use for the image window,
            where possible.
+        :type title: None or string
         """
 
         raise NotImplementedError()
@@ -473,7 +471,7 @@ class Image(object):
         image creates three new images each containing a copy of one of the
         original bands (red, green, blue).
 
-        @return A tuple containing bands.
+        :return: A tuple containing bands.
         """
 
         raise NotImplementedError()
@@ -481,8 +479,9 @@ class Image(object):
     def tell(self):
         """Returns the current frame number.
 
-        @return Frame number, starting with 0.
-        @see #Image.seek
+        :return: Frame number, starting with 0.
+
+        See :meth:`Image.seek`
         """
 
         raise NotImplementedError()
@@ -493,25 +492,24 @@ class Image(object):
         Make this image into a thumbnail. This method modifies the image to
         contain a thumbnail version of itself, no larger than the given size.
         This method calculates an appropriate thumbnail size to preserve the
-        aspect of the image, calls the {@link #Image.draft} method to
+        aspect of the image, calls the :meth:`Image.draft` method to
         configure the file reader (where applicable), and finally resizes the
         image.
 
-         Note that the bilinear and bicubic filters in the current version of
+        Note that the bilinear and bicubic filters in the current version of
         PIL are not well-suited for thumbnail generation. You should use
         ANTIALIAS unless speed is much more important than quality.
 
-         Also note that this function modifies the Image object in place. If
+        Also note that this function modifies the Image object in place. If
         you need to use the full resolution image as well, apply this method
-        to a {@link #Image.copy} of the original image.
+        to a :meth:`Image.copy` of the original image.
 
-        @param size Requested size.
-        @param resample Optional resampling filter.  This can be one
-           of NEAREST, BILINEAR, BICUBIC, or
-           ANTIALIAS (best quality).  If omitted, it defaults
-           to NEAREST (this will be changed to ANTIALIAS in a
-           future version).
-        @return None
+        :param size: Requested size.
+        :param resample: Optional resampling filter. This can be one of of
+            NEAREST, BILINEAR, BICUBIC, or ANTIALIAS (best quality). If omitted,
+            it defaults to NEAREST (this will be changed to ANTIALIAS in a future
+            version).
+        :rtype: None
         """
 
         raise NotImplementedError()
@@ -522,22 +520,21 @@ class Image(object):
         size, and the same mode as the original, and copies data to the new
         image using the given transform.
 
-        @def transform(size, method, data, resample=NEAREST)
-        @param size The output size.
-        @param method The transformation method.  This is one of
+        :param size: The output size.
+        :param method: The transformation method.  This is one of
           EXTENT (cut out a rectangular subregion), AFFINE
           (affine transform), PERSPECTIVE (perspective
           transform), QUAD (map a quadrilateral to a
           rectangle), or MESH (map a number of source quadrilaterals
           in one operation).
-        @param data Extra data to the transformation method.
-        @param resample Optional resampling filter.  It can be one of
+        :param data: Extra data to the transformation method.
+        :param resample: Optional resampling filter.  It can be one of
            NEAREST (use nearest neighbour), BILINEAR
            (linear interpolation in a 2x2 environment), or
            BICUBIC (cubic spline interpolation in a 4x4
            environment). If omitted, or if the image has mode
            "1" or "P", it is set to NEAREST.
-        @return An Image object.
+        :rtype: :class:Image object
         """
 
         raise NotImplementedError()
